Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(520)

Unified Diff: sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart

Issue 397843005: Lazily load the entrypoint. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Created 6 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart
diff --git a/sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart b/sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart
index 8294594a5cb0865b2cb5b96255fd91f3ec68b769..87c3a6987b26c2fba57a6792a8976f77d46c7231 100644
--- a/sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart
+++ b/sdk/lib/_internal/pub/lib/src/command/list_package_dirs.dart
@@ -49,8 +49,11 @@ class ListPackageDirsCommand extends PubCommand {
packages[entrypoint.root.name] = path.join(entrypoint.root.dir, "lib");
// Include the file(s) which when modified will affect the results. For pub,
- // that's just the lockfile.
- output["input_files"] = [entrypoint.lockFilePath];
+ // that's just the pubspec and lockfile.
+ output["input_files"] = [
+ entrypoint.lockFilePath,
+ entrypoint.pubspecPath
nweiz 2014/07/16 00:33:29 This doesn't actually read the pubspec anymore, do
Bob Nystrom 2014/07/16 17:33:24 It does, since we are touching "entrypoint" the ro
+ ];
return Future.wait(futures).then((_) {
log.json.message(output);
« no previous file with comments | « sdk/lib/_internal/pub/lib/src/command/help.dart ('k') | sdk/lib/_internal/pub/lib/src/command/uploader.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698